==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/lt-LT/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Šis naudotojas gali prisijungti',
    'activated_disabled_help_text' => 'Negalite redaguoti savo paskyros aktyvinimo būsenos.',
    'assets_user'       => 'Turtas išduotas :name',
    'bulk_update_warn'	=> 'Ketinate redaguoti :user_count naudotojų savybes. Atminkite, kad naudodami šią formą, savo naudotojo atributų keisti negalite – savo naudotoją turite redaguoti atskirai.',
    'bulk_update_help'	=> 'Ši forma suteikia galimybę atnaujinti iškart kelis naudotojus. Užpildykite tik tuos laukus, kuriuos norite pakeisti. Laukai, kuriuos paliksite tuščius, liks nepakeisti.',
    'current_assets'    => 'Šiam naudotojui išduotas turtas',
    'clone'             => 'Klonuoti naudotoją',
    'contact_user'      => 'Susisiekti su :name',
    'edit'              => 'Redaguoti naudotoją',
    'filetype_info'     => 'Leidžiami failų tipai yra: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar.',
    'history_user'      => ':name naudotojo istorija',
    'info'				=> 'Informacija',
    'restore_user'		=> 'Spustelėkite čia, kad juos atkurtumėte.',
    'last_login'        => 'Paskutinis prisijungimas',
    'ldap_config_text'  => 'LDAP konfigūracijos nustatymus rasite „Administratorius > Nustatymai“. Pasirinkta (neprivaloma) vieta bus priskirta visiems importuotiems naudotojams.',
    'print_assigned'    => 'Spausdinti išduotą',
    'email_assigned'    => 'El. paštu nusiųsti išduoto turto sąrašą',
    'user_notified'     => 'Naudotojui el. paštu išsiųstas jam priskirtų daiktų sąrašas.',
    'auto_assign_label' => 'Įtraukti šį naudotoją, kai automatiškai priskiriamos tinkamos licencijos',
    'auto_assign_help'  => 'Praleisti šį naudotoją, kai automatiškai priskiriamos licencijos',
    'software_user'     => 'Programinė įranga išduota: :name',
    'send_email_help'   => 'Turite nurodyti šio naudotojo el. pašto adresą, kad galėmtumėte jam nusiųsti prisijungimo duomenis. El. pašto prisijungimo duomenis galima siųsti tik kuriant naudotoją. Slaptažodžiai saugomi vienpuse maiša ir jų negalima atkurti po to, kai jie yra išsaugomi.',
    'view_user'         => 'Peržiūrėti naudotoją :name',
    'usercsv'           => 'CSV failas',
    'two_factor_admin_optin_help' => 'Dabartiniai administratoriaus nustatymai leidžia pasirinktinai naudoti dviejų veiksnių autentifikavimą.  ',
    'two_factor_enrolled' => '2FA įrenginys įtrauktas ',
    'two_factor_active'   => '2FA aktyvus ',
    'user_deactivated'  => 'Naudotojas negali prisijungti',
    'user_activated'  => 'Naudotojas gali prisijungti',
    'activation_status_warning' => 'Nekeisti aktyvinimo būsenos',
    'group_memberships_helpblock' => 'Tik superadministratoriai gali keisti grupių narystes.',
    'superadmin_permission_warning' => 'Tik superadministratoriai gali suteikti superadministratoriaus prieigą.',
    'admin_permission_warning' => 'Tik administratoriai ir aukštesnes teises turintys naudotojai gali suteikti administratoriaus prieigą.',
    'remove_group_memberships' => 'Pašalinti grupių narystes',
    'warning_deletion_information' => 'Ketinate paimti VISUS elementus iš žemiau išvardintų :count naudotojų. Superadministratorių vardai yra paryškinti raudonai.',
    'update_user_assets_status' => 'Atnaujinti viso šių naudotojų turto būsenas į šią būseną',
    'checkin_user_properties' => 'Paimti visą su šiais naudotojais susietą turtą',
    'remote_label'   => 'Tai nuotolinis naudotojas',
    'remote'   => 'Nuotolinis',
    'remote_help' => 'Tai gali būti naudinga, jei reikia filtruoti pagal nuotolinius naudotojus, kurie niekada arba retai atvyksta į jūsų fizines vietas.',
    'not_remote_label' => 'Tai ne nuotolinis naudotojas',
    'vip_label' => 'VIP naudotojas',
    'vip_help' => 'Tai gali būti naudinga pažymint svarbius žmones savo organizacijoje, jei norėtumėte su jais elgtis ypatingai.',
    'create_user' => 'Sukurti naudotoją',
    'create_user_page_explanation' => 'Tai yra paskyros informacija, kurią naudosite norėdami pirmą kartą prisijungti prie svetainės.',
    'email_credentials' => 'Siųsti prisijungimo duomenis',
    'email_credentials_text' => 'Išsiųskite mano prisijungimo duomenis aukščiau nurodytu el. pašto adresu',
    'next_save_user' => 'Toliau: išsaugoti naudotoją',
    'all_assigned_list_generation' => 'Sugeneruota:',
    'email_user_creds_on_create' => 'Siųsti naudotojui jo prisijungimo duomenis?',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/lt-LT/admin/users/general.php <==
<?php

return [
    'activated_help_text' => 'Šis naudotojas gali prisijungti',
    'activated_disabled_help_text' => 'Negalite redaguoti savo paskyros aktyvinimo būsenos.',
    'assets_user'       => 'Turtas išduotas :name',
    'bulk_update_warn'	=> 'Ketinate redaguoti :user_count naudotojų savybes. Atminkite, kad naudodami šią formą, savo naudotojo atributų keisti negalite – savo naudotoją turite redaguoti atskirai.',
    'bulk_update_help'	=> 'Ši forma suteikia galimybę atnaujinti iškart kelis naudotojus. Užpildykite tik tuos laukus, kuriuos norite pakeisti. Laukai, kuriuos paliksite tuščius, liks nepakeisti.',
    'current_assets'    => 'Šiam naudotojui išduotas turtas',
    'clone'             => 'Klonuoti naudotoją',
    'contact_user'      => 'Susisiekti su :name',
    'edit'              => 'Redaguoti naudotoją',
    'filetype_info'     => 'Leidžiami failų tipai yra: png, gif, jpg, jpeg, doc, docx, pdf, txt, zip, rar.',
    'history_user'      => ':name naudotojo istorija',
    'info'				=> 'Informacija',
    'restore_user'		=> 'Spustelėkite čia, kad juos atkurtumėte.',
    'last_login'        => 'Paskutinis prisijungimas',
    'ldap_config_text'  => 'LDAP konfigūracijos nustatymus rasite „Administratorius > Nustatymai“. Pasirinkta (neprivaloma) vieta bus priskirta visiems importuotiems naudotojams.',
    'print_assigned'    => 'Spausdinti išduotą',
    'email_assigned'    => 'El. paštu nusiųsti išduoto turto sąrašą',
    'user_notified'     => 'Naudotojui el. paštu išsiųstas jam priskirtų daiktų sąrašas.',
    'users_notified'    => 'The user has been emailed a list of their currently assigned items.|:count users have been emailed a list of their currently assigned items.',
    'users_notified_warning' => ':count user has been emailed a list of their currently assigned items, however :no_email users did not have an email address so could not be emailed.|:count users have been emailed a list of their currently assigned items, however :no_email user(s) did not have an email address so could not be emailed.',
    'auto_assign_label' => 'Įtraukti šį naudotoją, kai automatiškai priskiriamos tinkamos licencijos',
    'auto_assign_help'  => 'Praleisti šį naudotoją, kai automatiškai priskiriamos licencijos',
    'software_user'     => 'Programinė įranga išduota: :name',
    'send_email_help'   => 'Turite nurodyti šio naudotojo el. pašto adresą, kad galėmtumėte jam nusiųsti prisijungimo duomenis. El. pašto prisijungimo duomenis galima siųsti tik kuriant naudotoją. Slaptažodžiai saugomi vienpuse maiša ir jų negalima atkurti po to, kai jie yra išsaugomi.',
    'view_user'         => 'Peržiūrėti naudotoją :name',
    'usercsv'           => 'CSV failas',
    'two_factor_admin_optin_help' => 'Dabartiniai administratoriaus nustatymai leidžia pasirinktinai naudoti dviejų veiksnių autentifikavimą.  ',
    'two_factor_enrolled' => '2FA įrenginys įtrauktas ',
    'two_factor_active'   => '2FA aktyvus ',
    'user_deactivated'  => 'Naudotojas negali prisijungti',
    'user_activated'  => 'Naudotojas gali prisijungti',
    'activation_status_warning' => 'Nekeisti aktyvinimo būsenos',
    'group_memberships_helpblock' => 'Tik superadministratoriai gali keisti grupių narystes.',
    'superadmin_permission_warning' => 'Tik superadministratoriai gali suteikti superadministratoriaus prieigą.',
    'admin_permission_warning' => 'Tik administratoriai ir aukštesnes teises turintys naudotojai gali suteikti administratoriaus prieigą.',
    'remove_group_memberships' => 'Pašalinti grupių narystes',
    'warning_deletion_information' => 'Ketinate paimti VISUS elementus iš žemiau išvardintų :count naudotojų. Superadministratorių vardai yra paryškinti raudonai.',
    'update_user_assets_status' => 'Atnaujinti viso šių naudotojų turto būsenas į šią būseną',
    'checkin_user_properties' => 'Paimti visą su šiais naudotojais susietą turtą',
    'remote_label'   => 'Tai nuotolinis naudotojas',
    'remote'   => 'Nuotolinis',
    'remote_help' => 'Tai gali būti naudinga, jei reikia filtruoti pagal nuotolinius naudotojus, kurie niekada arba retai atvyksta į jūsų fizines vietas.',
    'not_remote_label' => 'Tai ne nuotolinis naudotojas',
    'vip_label' => 'VIP naudotojas',
    'vip_help' => 'Tai gali būti naudinga pažymint svarbius žmones savo organizacijoje, jei norėtumėte su jais elgtis ypatingai.',
    'create_user' => 'Sukurti naudotoją',
    'create_user_page_explanation' => 'Tai yra paskyros informacija, kurią naudosite norėdami pirmą kartą prisijungti prie svetainės.',
    'email_credentials' => 'Siųsti prisijungimo duomenis',
    'email_credentials_text' => 'Išsiųskite mano prisijungimo duomenis aukščiau nurodytu el. pašto adresu',
    'next_save_user' => 'Toliau: išsaugoti naudotoją',
    'all_assigned_list_generation' => 'Sugeneruota:',
    'email_user_creds_on_create' => 'Siųsti naudotojui jo prisijungimo duomenis?',
];
